# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019Firstroundnanojectnumber(str, Enum):
    """
    Enum class for Firstroundnanojectnumber
    """

    """
    allowed enum values
    """
    NA = 'N/A'
    NJ1 = 'NJ#1'
    NJ2 = 'NJ#2'
    NJ3 = 'NJ#3'
    NJ4 = 'NJ#4'
    NJ5 = 'NJ#5'
    NJ6 = 'NJ#6'
    NJ7 = 'NJ#7'
    NJ8 = 'NJ#8'
    SELECT = 'Select...'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019Firstroundnanojectnumber from a JSON string"""
        return cls(json.loads(json_str))


